@@ -47,7 +47,7 @@ fn test_inner_html_patch() {
         patch,
         vec![AddAttributes::new(
             &"article",
-            TreePath::start_at(1, vec![0, 0]),
+            TreePath::new(vec![0, 0]),
             vec![&inner_html("<h1>Lorep Ipsum</h1>")]
         )
         .into()]
@@ -69,7 +69,7 @@ fn test_inner_html_removed() {
         patch,
         vec![RemoveAttributes::new(
             &"article",
-            TreePath::start_at(1, vec![0, 0]),
+            TreePath::new(vec![0, 0]),
             vec![&inner_html("<h1>Lorep Ipsum</h1>")]
         )
         .into()]
